@@ -1,6 +1,6 @@
 /* abstract_crypto.c
  *
- * $Id: abstract_crypto.c,v 1.10 1999/11/28 17:32:57 nisse Exp $ */
+ * $Id: abstract_crypto.c,v 1.12 1999/12/09 22:19:06 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -93,6 +93,17 @@ hash_string(struct hash_algorithm *a,
   return out;
 }
 
+struct lsh_string *
+crypt_string(struct crypto_instance *c,
+	     struct lsh_string *in,
+	     int free)
+{
+  struct lsh_string *out = (free ? in : lsh_string_alloc(in->length));
+  CRYPT(c, in->length, in->data, out->data);
+  
+  return out;
+}
+
 
 /* FIXME: These functions don't really belong here. */
 
