@@ -2,7 +2,7 @@
  *
  * Information about ssh channels.
  *
- * $Id: channel.h,v 1.46 1999/10/11 20:34:40 nisse Exp $
+ * $Id: channel.h,v 1.47 1999/12/07 00:26:19 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -348,7 +348,8 @@ struct lsh_string *channel_transmit_extended(struct ssh_channel *channel,
 					     UINT32 type,
 					     struct lsh_string *data);
 
-extern struct command connection_service;
+extern struct command_simple connection_service_command;
+#define INIT_CONNECTION_SERVICE (&connection_service_command.super.super)
 
 
 #endif /* LSH_CHANNEL_H_INCLUDED */
