@@ -30,8 +30,6 @@
 #include "resource.h"
 #include "randomness.h"
 
-/* Forward declaration */
-struct ssh_connection;
 
 #define GABA_DECLARE
 #include "connection.h.x"
@@ -76,6 +74,7 @@ struct ssh_connection;
 
        ; Features or bugs peculiar to the peer
        (peer_flags simple UINT32)
+       (chain object ssh_connection)
 
        ; Cleanup
        (resources object resource_list)
