@@ -4,7 +4,7 @@
  * processes and ports. Used to kill or release the resource in
  * question when the connection dies.
  *
- * $Id: resource.h,v 1.8 1999/10/02 20:06:41 nisse Exp $ */
+ * $Id: resource.h,v 1.9 1999/12/12 19:34:06 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -60,30 +60,6 @@
 #define REMEMBER_RESOURCE(l, r) ((l)->remember((l), (r)))
 #define KILL_RESOURCE_LIST(l) KILL_RESOURCE(&(l)->super)
 
-
-#if 0
-/* ;;GABA:
-   (class
-     (name resource_list)
-     (vars
-       ;; (q struct object_queue)
-       ;;(q special-struct "struct lsh_queue"
-       ;;                  do_mark_resources do_free_resources)
-
-       (q special "struct resource_node *"
-                  do_mark_resources do_free_resources)       
-       (remember method void "struct resource *r")
-
-       ; Kills the resource and unlinks and deallocates the node.
-       ;; (kill_resource method void "struct resource_node *n")
-       
-       (kill_all method void)))
-*/
-#endif
-
-/* #define KILL_RESOURCE_NODE(l, n) ((l)->kill_resource((l), (n))) */
-
-
 /* Allocates an empty list. */
 struct resource_list *empty_resource_list(void);
 
